# -*- coding: utf-8 -*-

# django-xls2po
# xls2po/utils.py

from __future__ import unicode_literals
import sys
import os
import logging

import polib
import xlrd


__all__ = [
    "XlsToPo",
]


class XlsToPo(object):

    logger = logging.getLogger(__name__)

    def __init__(self, src, *args, **kwargs):
        """
        Init conversion.
        Args:
            src: (unicode or string) path to ".xls" file.
        """
        self.quiet = kwargs.pop("quiet", False)

        if os.path.exists(src):
            self.src = src
        else:
            if not self.quiet:
                sys.stderr.write("ERROR: File '{src}' does not exists.".format(**{"src": src, }))
            self.logger.error("ERROR: File '{src}' does not exists.".format(**{"src": src, }))
            sys.exit(-1)

        self.xls = xlrd.open_workbook(self.src)
        self.po = polib.POFile()

    def output(self):
        """
        Create full path for .po file.
        Returns:
            unicode: full path for .po file to save parsed translations strings from excel file.
        """

        path, src = os.path.split(self.src)
        src, ext = os.path.splitext(src)

        return os.path.join(path, "{src}.po".format(**{"src": src, }))

    def metadata(self):
        """
        Write metadata to .po.
        """

        sheet = self.xls.sheet_by_name("metadata")
        n = sheet.nrows
        metadata = {}

        for row_i in range(1, n):
            row = sheet.row_values(row_i)
            metadata[row[0]] = row[1]

        self.po.metadata = metadata

    def strings(self):
        """
        Write strings to .po.
        """

        sheet = self.xls.sheet_by_name("strings")
        n = sheet.nrows

        for row_i in range(1, n):
            row = sheet.row_values(row_i)
            entry = polib.POEntry(
                msgid=row[0],
                msgstr=row[1],
            )
            self.po.append(entry)

    def convert(self, *args, **kwargs):
        """
        Yes it is, thanks captain.
        """

        self.metadata()
        self.strings()

        self.po.save(self.output())



# -*- coding: utf-8 -*-

# django-xls2po
# xls2po/management/commands/xls-to-po.py

from __future__ import unicode_literals
import os
from optparse import make_option

from django.core.management.base import BaseCommand
from django.conf import settings

from rosetta.poutil import find_pos

from xls2po.utils import XlsToPo


class Command(BaseCommand):
    """
    Convert django-xls2po generated .xls files to .po.
    """

    all = "all"

    option_list = BaseCommand.option_list + (
        make_option("--language", "-l", dest="language", help="Language", default=all),
        make_option("--quiet", "-q", dest="quiet", help="Be quiet", default=False, action="store_true"),
    )

    def handle(self, *args, **kwargs):

        if kwargs["language"] == self.all:
            for language in dict(settings.LANGUAGES).keys():
                self.convert(language)
        else:
            self.convert(kwargs["language"])

    def convert(self, language, *args, **kwargs):
        """
        Run converter.
        Args:
            language: (unicode) language code.
        """

        for f in find_pos(language):
            XlsToPo(self.input(f), **kwargs).convert()

    def input(self, f):
        """
        Create full path for .xls file.
        Args:
            f: (unicode) ".po" file path.
        Returns:
            unicode: path to ".po" file.
        """

        path, f = os.path.split(f)
        f, ext = os.path.splitext(f)

        return os.path.join(path, "{f}.xls".format(**{"f": f, }))
